import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import CampaignService from '@/service/campaign/campaign-service';
import EditViewEngine from '@engine/view/edit-view-engine';

/**
 * 日程安排视图基类
 *
 * @export
 * @class CampaignInfo_ScheduleBase
 * @extends {EditViewBase}
 */
export class CampaignInfo_ScheduleBase extends EditViewBase {

    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof CampaignInfo_ScheduleBase
     */
    protected appDeName: string = 'campaign';

    /**
     * 实体服务对象
     *
     * @type {CampaignService}
     * @memberof CampaignInfo_ScheduleBase
     */
    protected appEntityService: CampaignService = new CampaignService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof CampaignInfo_ScheduleBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof CampaignInfo_ScheduleBase
     */
    protected model: any = {
        srfCaption: 'entities.campaign.views.info_schedule.caption',
        srfTitle: 'entities.campaign.views.info_schedule.title',
        srfSubTitle: 'entities.campaign.views.info_schedule.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof CampaignInfo_ScheduleBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'f63525be2835a01da997d7f059efb09f';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof CampaignInfo_ScheduleBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof CampaignInfo_ScheduleBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'campaign',
            majorPSDEField: 'campaignname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof CampaignInfo_ScheduleBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof CampaignInfo_ScheduleBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof CampaignInfo_ScheduleBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}